# Functions common to tests
#
# Copyright (C) 2018, 2019 Patrick McDermott
#
# This file is part of opkbuild.
#
# opkbuild is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# opkbuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with opkbuild.  If not, see <http://www.gnu.org/licenses/>.

is()
{
	local description="${1}"
	local got="${2}"
	local expected="${3}"
	shift 3

	if [ "x${got}" = "x${expected}" ]; then
		ok_ -- "${description}"
	else
		not_ok_ -- "${description}"
		diag_ " Failed test '${description}'"
		diag_ "         got: '${got}'"
		diag_ "    expected: '${expected}'"
	fi
}

cmd_is()
{
	local description="${1}"
	shift 1
	local ok=
	local eof=
	local got=
	local exp=

	ok=true
	exec 3<<-EOF
		$("${@}")
		EOF
	while :; do
		eof=0
		read -r got <&3 || eof=$((${eof} + 1))
		read -r exp <&0 || eof=$((${eof} + 2))
		[ ${eof} -eq 3 ] && break
		[ x"${got}" = x"${exp}" ] && continue
		if ${ok}; then
			not_ok_ -- "${description}"
			diag_ " Failed test '${description}'"
			ok=false
		fi
		diag_ "         got: '${got}'"
		diag_ "    expected: '${exp}'"
	done
	exec 3<&-

	if ${ok}; then
		ok_ -- "${description}"
	fi
}

FOO_SH="$(cat <<-'EOF'
	#!/bin/sh
	printf 'Hello, world!\n'
	EOF
	)"
FOO_SH_PATCHED="$(cat <<-'EOF'
	#!/bin/sh
	printf 'Goodbye, world!\n'
	EOF
	)"

# SPF 2.0 environment variables:
#   <http://specs.proteanos.com/spf-2.0/buildsys.html#env-vars>
# Section 7.3.1 Package Variables
export OPK_SOURCE='foo'
export OPK_SOURCE_VERSION='1.0-1'
export OPK_SOURCE_VERSION_UPSTREAM='1.0'
export OPK_BINARY_VERSION='1.0-1'
export OPK_PACKAGES='foo baz-qux bar'
export OPK_PACKAGES_REDUCED='foo baz-qux bar'
# Section 7.3.2 Build and Host System Variables
# OPK_BUILD_ARCH_GNU and OPK_HOST_ARCH_GNU aren't set or used by opkbuild
# utilities.  These should be removed from the SPF.
export OPK_BUILD_ARCH='amd64-linux-glibc'
export OPK_BUILD_ARCH_CPU='amd64'
export OPK_BUILD_ARCH_KERNEL='linux'
export OPK_BUILD_ARCH_LIBS='glibc'
export OPK_BUILD_PLAT='dev'
export OPK_HOST_ARCH='i686-linux-glibc'
export OPK_HOST_ARCH_CPU='i686'
export OPK_HOST_ARCH_KERNEL='linux'
export OPK_HOST_ARCH_LIBS='glibc'
export OPK_HOST_PLAT='x60'
# Section 7.3.3 Toolchain Variables aren't used by opkbuild utilities.

# For out-of-tree builds, copy test package files to build directory.
rm -Rf "${TOP_BUILDDIR}/tests/data.build/"
cp -Rp "${TOP_SRCDIR}/tests/data/" "${TOP_BUILDDIR}/tests/data.build/"
chmod -R u+w "${TOP_BUILDDIR}/tests/data.build/"  # Automake makes files RO
mkdir -p "${TOP_BUILDDIR}/tests/data.build/pkg/tmp/"
cd "${TOP_BUILDDIR}/tests/data.build/pkg/tmp/"
